---
title: wikipedia
---

<!-- ABM和SES这些概念，都涉及非常专业的具体领域，很少有研究者两者同时涉足。为了说明ABSESpy为什么要将两者结合，或者帮助关注该方法的学者熟悉这两个领域中的某些概念，我们创建了这个百科页面。作者团队参考公开发表的、经过同行评议的论文，努力做到言简意赅且依据详实。 -->
The concepts of ABM and SES involve very specialized specific fields, with few researchers venturing into both at the same time.
To illustrate why `ABSESpy` combines these two, or to help scholars interested in this method familiarize themselves with some concepts in these two fields, we have created this encyclopedia page.

<!-- 我们更希望相关领域的学者愿意参与到本百科页的共建中，如果发现任何错误，请及时与我们联系。 -->

> [!INFO]In Progress
> The author team refers to publicly published, peer-reviewed papers, striving for simplicity and factual accuracy. We sincerely hope that scholars in related fields are willing to participate in the co-construction of this encyclopedia page. If any errors are found, please [contact us promptly](https://github.com/SongshGeoLab/ABSESpy/issues).


<div class="grid" markdown>

[:books: __Concepts__](concepts.md) Introduction of basic related concepts
{ .card }

[:books: __Materials__](materials.md) Useful links for learning the background
{ .card }

[:books: __Refers__](about.md) Some awesome academic refers that the `ABSESpy` used
{ .card }

[:books: __Paper__](../paper/paper.md) A paper introduces how `ABSESpy` helps this realm
{ .card }

</div>
